# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import modern_logic_client
from modern_logic_client.api.alerts_api import AlertsApi  # noqa: E501
from modern_logic_client.rest import ApiException


class TestAlertsApi(unittest.TestCase):
    """AlertsApi unit test stubs"""

    def setUp(self):
        self.api = AlertsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_alert_alert_id_get(self):
        """Test case for alert_alert_id_get

        Get Alert Details  # noqa: E501
        """
        pass

    def test_alert_get(self):
        """Test case for alert_get

        List Alerts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'webhook_id': 'int',
        'workflow_id': 'int',
        'workflow_version': 'int',
        'execution_id': 'int',
        'customer_id': 'int',
        'customer_url': 'str',
        'alert_id': 'int',
        'description': 'str',
        'event': 'str',
        'event_metadata': 'object'
    }

    attribute_map = {
        'webhook_id': 'webhookId',
        'workflow_id': 'workflowId',
        'workflow_version': 'workflowVersion',
        'execution_id': 'executionId',
        'customer_id': 'customerId',
        'customer_url': 'customerUrl',
        'alert_id': 'alertId',
        'description': 'description',
        'event': 'event',
        'event_metadata': 'event_metadata'
    }

    def __init__(self, webhook_id=None, workflow_id=None, workflow_version=None, execution_id=None, customer_id=None, customer_url=None, alert_id=None, description=None, event=None, event_metadata=None):  # noqa: E501
        """WebhookResponse - a model defined in Swagger"""  # noqa: E501
        self._webhook_id = None
        self._workflow_id = None
        self._workflow_version = None
        self._execution_id = None
        self._customer_id = None
        self._customer_url = None
        self._alert_id = None
        self._description = None
        self._event = None
        self._event_metadata = None
        self.discriminator = None
        if webhook_id is not None:
            self.webhook_id = webhook_id
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if workflow_version is not None:
            self.workflow_version = workflow_version
        if execution_id is not None:
            self.execution_id = execution_id
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_url is not None:
            self.customer_url = customer_url
        if alert_id is not None:
            self.alert_id = alert_id
        if description is not None:
            self.description = description
        if event is not None:
            self.event = event
        if event_metadata is not None:
            self.event_metadata = event_metadata

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookResponse.  # noqa: E501


        :return: The webhook_id of this WebhookResponse.  # noqa: E501
        :rtype: int
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookResponse.


        :param webhook_id: The webhook_id of this WebhookResponse.  # noqa: E501
        :type: int
        """

        self._webhook_id = webhook_id

    @property
    def workflow_id(self):
        """Gets the workflow_id of this WebhookResponse.  # noqa: E501


        :return: The workflow_id of this WebhookResponse.  # noqa: E501
        :rtype: int
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this WebhookResponse.


        :param workflow_id: The workflow_id of this WebhookResponse.  # noqa: E501
        :type: int
        """

        self._workflow_id = workflow_id

    @property
    def workflow_version(self):
        """Gets the workflow_version of this WebhookResponse.  # noqa: E501


        :return: The workflow_version of this WebhookResponse.  # noqa: E501
        :rtype: int
        """
        return self._workflow_version

    @workflow_version.setter
    def workflow_version(self, workflow_version):
        """Sets the workflow_version of this WebhookResponse.


        :param workflow_version: The workflow_version of this WebhookResponse.  # noqa: E501
        :type: int
        """

        self._workflow_version = workflow_version

    @property
    def execution_id(self):
        """Gets the execution_id of this WebhookResponse.  # noqa: E501


        :return: The execution_id of this WebhookResponse.  # noqa: E501
        :rtype: int
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this WebhookResponse.


        :param execution_id: The execution_id of this WebhookResponse.  # noqa: E501
        :type: int
        """

        self._execution_id = execution_id

    @property
    def customer_id(self):
        """Gets the customer_id of this WebhookResponse.  # noqa: E501


        :return: The customer_id of this WebhookResponse.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this WebhookResponse.


        :param customer_id: The customer_id of this WebhookResponse.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_url(self):
        """Gets the customer_url of this WebhookResponse.  # noqa: E501


        :return: The customer_url of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._customer_url

    @customer_url.setter
    def customer_url(self, customer_url):
        """Sets the customer_url of this WebhookResponse.


        :param customer_url: The customer_url of this WebhookResponse.  # noqa: E501
        :type: str
        """

        self._customer_url = customer_url

    @property
    def alert_id(self):
        """Gets the alert_id of this WebhookResponse.  # noqa: E501


        :return: The alert_id of this WebhookResponse.  # noqa: E501
        :rtype: int
        """
        return self._alert_id

    @alert_id.setter
    def alert_id(self, alert_id):
        """Sets the alert_id of this WebhookResponse.


        :param alert_id: The alert_id of this WebhookResponse.  # noqa: E501
        :type: int
        """

        self._alert_id = alert_id

    @property
    def description(self):
        """Gets the description of this WebhookResponse.  # noqa: E501


        :return: The description of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WebhookResponse.


        :param description: The description of this WebhookResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def event(self):
        """Gets the event of this WebhookResponse.  # noqa: E501


        :return: The event of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this WebhookResponse.


        :param event: The event of this WebhookResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["WORKFLOW_EXECUTED", "CUSTOMER_STATUS_CHANGED"]  # noqa: E501
        if event not in allowed_values:
            raise ValueError(
                "Invalid value for `event` ({0}), must be one of {1}"  # noqa: E501
                .format(event, allowed_values)
            )

        self._event = event

    @property
    def event_metadata(self):
        """Gets the event_metadata of this WebhookResponse.  # noqa: E501


        :return: The event_metadata of this WebhookResponse.  # noqa: E501
        :rtype: object
        """
        return self._event_metadata

    @event_metadata.setter
    def event_metadata(self, event_metadata):
        """Sets the event_metadata of this WebhookResponse.


        :param event_metadata: The event_metadata of this WebhookResponse.  # noqa: E501
        :type: object
        """

        self._event_metadata = event_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from modern_logic_client.api.alerts_api import AlertsApi
from modern_logic_client.api.customers_api import CustomersApi
from modern_logic_client.api.data_sources_api import DataSourcesApi
from modern_logic_client.api.executions_api import ExecutionsApi
from modern_logic_client.api.webhooks_api import WebhooksApi
from modern_logic_client.api.workflows_api import WorkflowsApi
# import ApiClient
from modern_logic_client.api_client import ApiClient
from modern_logic_client.configuration import Configuration
# import models into sdk package
from modern_logic_client.models.alert import Alert
from modern_logic_client.models.alert_item import AlertItem
from modern_logic_client.models.customer import Customer
from modern_logic_client.models.customer_item import CustomerItem
from modern_logic_client.models.data_source import DataSource
from modern_logic_client.models.data_source_call import DataSourceCall
from modern_logic_client.models.data_source_call_item import DataSourceCallItem
from modern_logic_client.models.data_source_type import DataSourceType
from modern_logic_client.models.execution import Execution
from modern_logic_client.models.execution_input import ExecutionInput
from modern_logic_client.models.execution_item import ExecutionItem
from modern_logic_client.models.inline_response200 import InlineResponse200
from modern_logic_client.models.inline_response2001 import InlineResponse2001
from modern_logic_client.models.inline_response2002 import InlineResponse2002
from modern_logic_client.models.inline_response2003 import InlineResponse2003
from modern_logic_client.models.inline_response2004 import InlineResponse2004
from modern_logic_client.models.inline_response2005 import InlineResponse2005
from modern_logic_client.models.inline_response2006 import InlineResponse2006
from modern_logic_client.models.inline_response2007 import InlineResponse2007
from modern_logic_client.models.inline_response2008 import InlineResponse2008
from modern_logic_client.models.list_response import ListResponse
from modern_logic_client.models.rule_set_warning import RuleSetWarning
from modern_logic_client.models.rule_warning import RuleWarning
from modern_logic_client.models.webhook import Webhook
from modern_logic_client.models.webhook_response import WebhookResponse
from modern_logic_client.models.workflow import Workflow
from modern_logic_client.models.workflow_execution_result import WorkflowExecutionResult
from modern_logic_client.models.workflow_version import WorkflowVersion



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkflowVersion(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'int',
        'name': 'str',
        'publish_date': 'date',
        'is_active': 'bool'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'name': 'name',
        'publish_date': 'publishDate',
        'is_active': 'isActive'
    }

    def __init__(self, version_number=None, name=None, publish_date=None, is_active=None):  # noqa: E501
        """WorkflowVersion - a model defined in Swagger"""  # noqa: E501
        self._version_number = None
        self._name = None
        self._publish_date = None
        self._is_active = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        if name is not None:
            self.name = name
        if publish_date is not None:
            self.publish_date = publish_date
        if is_active is not None:
            self.is_active = is_active

    @property
    def version_number(self):
        """Gets the version_number of this WorkflowVersion.  # noqa: E501


        :return: The version_number of this WorkflowVersion.  # noqa: E501
        :rtype: int
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this WorkflowVersion.


        :param version_number: The version_number of this WorkflowVersion.  # noqa: E501
        :type: int
        """

        self._version_number = version_number

    @property
    def name(self):
        """Gets the name of this WorkflowVersion.  # noqa: E501


        :return: The name of this WorkflowVersion.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowVersion.


        :param name: The name of this WorkflowVersion.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def publish_date(self):
        """Gets the publish_date of this WorkflowVersion.  # noqa: E501


        :return: The publish_date of this WorkflowVersion.  # noqa: E501
        :rtype: date
        """
        return self._publish_date

    @publish_date.setter
    def publish_date(self, publish_date):
        """Sets the publish_date of this WorkflowVersion.


        :param publish_date: The publish_date of this WorkflowVersion.  # noqa: E501
        :type: date
        """

        self._publish_date = publish_date

    @property
    def is_active(self):
        """Gets the is_active of this WorkflowVersion.  # noqa: E501


        :return: The is_active of this WorkflowVersion.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this WorkflowVersion.


        :param is_active: The is_active of this WorkflowVersion.  # noqa: E501
        :type: bool
        """

        self._is_active = is_active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import modern_logic_client
from modern_logic_client.models.inline_response2008 import InlineResponse2008  # noqa: E501
from modern_logic_client.rest import ApiException


class TestInlineResponse2008(unittest.TestCase):
    """InlineResponse2008 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse2008(self):
        """Test InlineResponse2008"""
        # FIXME: construct object with mandatory attributes with example values
        # model = modern_logic_client.models.inline_response2008.InlineResponse2008()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from modern_logic_client.api.alerts_api import AlertsApi
from modern_logic_client.api.customers_api import CustomersApi
from modern_logic_client.api.data_sources_api import DataSourcesApi
from modern_logic_client.api.executions_api import ExecutionsApi
from modern_logic_client.api.webhooks_api import WebhooksApi
from modern_logic_client.api.workflows_api import WorkflowsApi



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from modern_logic_client.api_client import ApiClient


class WorkflowsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def workflow_get(self, **kwargs):  # noqa: E501
        """List Available Workflows  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workflow_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.workflow_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def workflow_get_with_http_info(self, **kwargs):  # noqa: E501
        """List Available Workflows  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workflow_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflow', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workflow_workflow_id_execute_post(self, body, workflow_id, **kwargs):  # noqa: E501
        """Execute Workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_execute_post(body, workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param dict(str, object) body: Execution Information (required)
        :param int workflow_id: Workflow id (required)
        :param int v: If you want to run a version other then the current production version, you can supply the version number to run.
        :return: WorkflowExecutionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workflow_workflow_id_execute_post_with_http_info(body, workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflow_workflow_id_execute_post_with_http_info(body, workflow_id, **kwargs)  # noqa: E501
            return data

    def workflow_workflow_id_execute_post_with_http_info(self, body, workflow_id, **kwargs):  # noqa: E501
        """Execute Workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_execute_post_with_http_info(body, workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param dict(str, object) body: Execution Information (required)
        :param int workflow_id: Workflow id (required)
        :param int v: If you want to run a version other then the current production version, you can supply the version number to run.
        :return: WorkflowExecutionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'workflow_id', 'v']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workflow_workflow_id_execute_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `workflow_workflow_id_execute_post`")  # noqa: E501
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params or
                params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflow_workflow_id_execute_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_id' in params:
            path_params['workflowID'] = params['workflow_id']  # noqa: E501

        query_params = []
        if 'v' in params:
            query_params.append(('v', params['v']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflow/{workflowID}/execute', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowExecutionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workflow_workflow_id_executions_get(self, workflow_id, **kwargs):  # noqa: E501
        """List Workflow Executions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_executions_get(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow Id (required)
        :param int v: If you want to return the executions of a particular workflow version instead of all workflows
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workflow_workflow_id_executions_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflow_workflow_id_executions_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflow_workflow_id_executions_get_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """List Workflow Executions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_executions_get_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow Id (required)
        :param int v: If you want to return the executions of a particular workflow version instead of all workflows
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workflow_id', 'v', 'page_size', 'page_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workflow_workflow_id_executions_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params or
                params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflow_workflow_id_executions_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_id' in params:
            path_params['workflowID'] = params['workflow_id']  # noqa: E501

        query_params = []
        if 'v' in params:
            query_params.append(('v', params['v']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflow/{workflowID}/executions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workflow_workflow_id_get(self, workflow_id, **kwargs):  # noqa: E501
        """Get Workflow Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_get(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow id (required)
        :return: Workflow
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workflow_workflow_id_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflow_workflow_id_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflow_workflow_id_get_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """Get Workflow Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_get_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow id (required)
        :return: Workflow
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workflow_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workflow_workflow_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params or
                params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflow_workflow_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_id' in params:
            path_params['workflowID'] = params['workflow_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflow/{workflowID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Workflow',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workflow_workflow_id_versions_get(self, workflow_id, **kwargs):  # noqa: E501
        """List Workflow Versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_versions_get(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow id (required)
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workflow_workflow_id_versions_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflow_workflow_id_versions_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflow_workflow_id_versions_get_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """List Workflow Versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_versions_get_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow id (required)
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workflow_id', 'page_size', 'page_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workflow_workflow_id_versions_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params or
                params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflow_workflow_id_versions_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_id' in params:
            path_params['workflowID'] = params['workflow_id']  # noqa: E501

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflow/{workflowID}/versions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workflow_workflow_id_webhooks_get(self, workflow_id, **kwargs):  # noqa: E501
        """List Active Callbacks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_webhooks_get(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow ID (required)
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workflow_workflow_id_webhooks_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflow_workflow_id_webhooks_get_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflow_workflow_id_webhooks_get_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """List Active Callbacks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflow_workflow_id_webhooks_get_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int workflow_id: Workflow ID (required)
        :param int page_size: Number of elements to return (default is 10)
        :param int page_number: Lists are ordered by creation date ascending. To return the first page, set pageNumber to zero
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workflow_id', 'page_size', 'page_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workflow_workflow_id_webhooks_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params or
                params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflow_workflow_id_webhooks_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_id' in params:
            path_params['workflowID'] = params['workflow_id']  # noqa: E501

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflow/{workflowID}/webhooks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Customer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'extra_properties': 'object',
        'customer_id': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'phone': 'str',
        'address_street': 'str',
        'address_street2': 'str',
        'address_city': 'str',
        'address_state_code': 'str',
        'address_zip': 'str',
        'address_country_code': 'str',
        'dob': 'date'
    }

    attribute_map = {
        'extra_properties': 'extraProperties',
        'customer_id': 'customerId',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'phone': 'phone',
        'address_street': 'addressStreet',
        'address_street2': 'addressStreet2',
        'address_city': 'addressCity',
        'address_state_code': 'addressStateCode',
        'address_zip': 'addressZip',
        'address_country_code': 'addressCountryCode',
        'dob': 'dob'
    }

    def __init__(self, extra_properties=None, customer_id=None, first_name=None, last_name=None, email=None, phone=None, address_street=None, address_street2=None, address_city=None, address_state_code=None, address_zip=None, address_country_code=None, dob=None):  # noqa: E501
        """Customer - a model defined in Swagger"""  # noqa: E501
        self._extra_properties = None
        self._customer_id = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._phone = None
        self._address_street = None
        self._address_street2 = None
        self._address_city = None
        self._address_state_code = None
        self._address_zip = None
        self._address_country_code = None
        self._dob = None
        self.discriminator = None
        if extra_properties is not None:
            self.extra_properties = extra_properties
        if customer_id is not None:
            self.customer_id = customer_id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if phone is not None:
            self.phone = phone
        if address_street is not None:
            self.address_street = address_street
        if address_street2 is not None:
            self.address_street2 = address_street2
        if address_city is not None:
            self.address_city = address_city
        if address_state_code is not None:
            self.address_state_code = address_state_code
        if address_zip is not None:
            self.address_zip = address_zip
        if address_country_code is not None:
            self.address_country_code = address_country_code
        if dob is not None:
            self.dob = dob

    @property
    def extra_properties(self):
        """Gets the extra_properties of this Customer.  # noqa: E501


        :return: The extra_properties of this Customer.  # noqa: E501
        :rtype: object
        """
        return self._extra_properties

    @extra_properties.setter
    def extra_properties(self, extra_properties):
        """Sets the extra_properties of this Customer.


        :param extra_properties: The extra_properties of this Customer.  # noqa: E501
        :type: object
        """

        self._extra_properties = extra_properties

    @property
    def customer_id(self):
        """Gets the customer_id of this Customer.  # noqa: E501

        Way that you uniquely identify customers  # noqa: E501

        :return: The customer_id of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this Customer.

        Way that you uniquely identify customers  # noqa: E501

        :param customer_id: The customer_id of this Customer.  # noqa: E501
        :type: str
        """

        self._customer_id = customer_id

    @property
    def first_name(self):
        """Gets the first_name of this Customer.  # noqa: E501

        Legal first name of the user being evaluated.  # noqa: E501

        :return: The first_name of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Customer.

        Legal first name of the user being evaluated.  # noqa: E501

        :param first_name: The first_name of this Customer.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Customer.  # noqa: E501

        Legal last name (surname) of the user being evaluated.  # noqa: E501

        :return: The last_name of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Customer.

        Legal last name (surname) of the user being evaluated.  # noqa: E501

        :param last_name: The last_name of this Customer.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this Customer.  # noqa: E501

        Email address provided by user being evaluated.  # noqa: E501

        :return: The email of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Customer.

        Email address provided by user being evaluated.  # noqa: E501

        :param email: The email of this Customer.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def phone(self):
        """Gets the phone of this Customer.  # noqa: E501

        Phone number of user being evaluated.  # noqa: E501

        :return: The phone of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this Customer.

        Phone number of user being evaluated.  # noqa: E501

        :param phone: The phone of this Customer.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def address_street(self):
        """Gets the address_street of this Customer.  # noqa: E501

        Home address of user being evaluated  # noqa: E501

        :return: The address_street of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._address_street

    @address_street.setter
    def address_street(self, address_street):
        """Sets the address_street of this Customer.

        Home address of user being evaluated  # noqa: E501

        :param address_street: The address_street of this Customer.  # noqa: E501
        :type: str
        """

        self._address_street = address_street

    @property
    def address_street2(self):
        """Gets the address_street2 of this Customer.  # noqa: E501


        :return: The address_street2 of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._address_street2

    @address_street2.setter
    def address_street2(self, address_street2):
        """Sets the address_street2 of this Customer.


        :param address_street2: The address_street2 of this Customer.  # noqa: E501
        :type: str
        """

        self._address_street2 = address_street2

    @property
    def address_city(self):
        """Gets the address_city of this Customer.  # noqa: E501


        :return: The address_city of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._address_city

    @address_city.setter
    def address_city(self, address_city):
        """Sets the address_city of this Customer.


        :param address_city: The address_city of this Customer.  # noqa: E501
        :type: str
        """

        self._address_city = address_city

    @property
    def address_state_code(self):
        """Gets the address_state_code of this Customer.  # noqa: E501


        :return: The address_state_code of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._address_state_code

    @address_state_code.setter
    def address_state_code(self, address_state_code):
        """Sets the address_state_code of this Customer.


        :param address_state_code: The address_state_code of this Customer.  # noqa: E501
        :type: str
        """

        self._address_state_code = address_state_code

    @property
    def address_zip(self):
        """Gets the address_zip of this Customer.  # noqa: E501


        :return: The address_zip of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._address_zip

    @address_zip.setter
    def address_zip(self, address_zip):
        """Sets the address_zip of this Customer.


        :param address_zip: The address_zip of this Customer.  # noqa: E501
        :type: str
        """

        self._address_zip = address_zip

    @property
    def address_country_code(self):
        """Gets the address_country_code of this Customer.  # noqa: E501


        :return: The address_country_code of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._address_country_code

    @address_country_code.setter
    def address_country_code(self, address_country_code):
        """Sets the address_country_code of this Customer.


        :param address_country_code: The address_country_code of this Customer.  # noqa: E501
        :type: str
        """

        self._address_country_code = address_country_code

    @property
    def dob(self):
        """Gets the dob of this Customer.  # noqa: E501

        Date of birth for user being evaluated  # noqa: E501

        :return: The dob of this Customer.  # noqa: E501
        :rtype: date
        """
        return self._dob

    @dob.setter
    def dob(self, dob):
        """Sets the dob of this Customer.

        Date of birth for user being evaluated  # noqa: E501

        :param dob: The dob of this Customer.  # noqa: E501
        :type: date
        """

        self._dob = dob

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Customer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Customer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "modern-logic-client"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Modern Logic Api",
    license='MIT',
    author_email="info@usemodernlogic.com",
    url = 'https://github.com/latourette359/modern_logic_client',
    download_url = "https://github.com/latourette359/modern_logic_client/archive/refs/tags/1.0.0.tar.gz",
    keywords=["Swagger", "Modern Logic Api"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Manage and version your customer decision logic outside of your codebase  # noqa: E501
    """
)



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DataSourceCall(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'execution_id': 'int',
        'data_source_id': 'int',
        'request': 'object',
        'response': 'object',
        'date_time_of_call': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'execution_id': 'executionId',
        'data_source_id': 'dataSourceId',
        'request': 'request',
        'response': 'response',
        'date_time_of_call': 'dateTimeOfCall'
    }

    def __init__(self, id=None, execution_id=None, data_source_id=None, request=None, response=None, date_time_of_call=None):  # noqa: E501
        """DataSourceCall - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._execution_id = None
        self._data_source_id = None
        self._request = None
        self._response = None
        self._date_time_of_call = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if execution_id is not None:
            self.execution_id = execution_id
        if data_source_id is not None:
            self.data_source_id = data_source_id
        if request is not None:
            self.request = request
        if response is not None:
            self.response = response
        if date_time_of_call is not None:
            self.date_time_of_call = date_time_of_call

    @property
    def id(self):
        """Gets the id of this DataSourceCall.  # noqa: E501


        :return: The id of this DataSourceCall.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DataSourceCall.


        :param id: The id of this DataSourceCall.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def execution_id(self):
        """Gets the execution_id of this DataSourceCall.  # noqa: E501


        :return: The execution_id of this DataSourceCall.  # noqa: E501
        :rtype: int
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this DataSourceCall.


        :param execution_id: The execution_id of this DataSourceCall.  # noqa: E501
        :type: int
        """

        self._execution_id = execution_id

    @property
    def data_source_id(self):
        """Gets the data_source_id of this DataSourceCall.  # noqa: E501


        :return: The data_source_id of this DataSourceCall.  # noqa: E501
        :rtype: int
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this DataSourceCall.


        :param data_source_id: The data_source_id of this DataSourceCall.  # noqa: E501
        :type: int
        """

        self._data_source_id = data_source_id

    @property
    def request(self):
        """Gets the request of this DataSourceCall.  # noqa: E501


        :return: The request of this DataSourceCall.  # noqa: E501
        :rtype: object
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this DataSourceCall.


        :param request: The request of this DataSourceCall.  # noqa: E501
        :type: object
        """

        self._request = request

    @property
    def response(self):
        """Gets the response of this DataSourceCall.  # noqa: E501


        :return: The response of this DataSourceCall.  # noqa: E501
        :rtype: object
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this DataSourceCall.


        :param response: The response of this DataSourceCall.  # noqa: E501
        :type: object
        """

        self._response = response

    @property
    def date_time_of_call(self):
        """Gets the date_time_of_call of this DataSourceCall.  # noqa: E501


        :return: The date_time_of_call of this DataSourceCall.  # noqa: E501
        :rtype: datetime
        """
        return self._date_time_of_call

    @date_time_of_call.setter
    def date_time_of_call(self, date_time_of_call):
        """Sets the date_time_of_call of this DataSourceCall.


        :param date_time_of_call: The date_time_of_call of this DataSourceCall.  # noqa: E501
        :type: datetime
        """

        self._date_time_of_call = date_time_of_call

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataSourceCall, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataSourceCall):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkflowExecutionResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'flags': 'list[str]',
        'warnings': 'list[RuleSetWarning]',
        'execution_id': 'int',
        'result': 'str',
        'score': 'str',
        'reason': 'list[str]',
        'date_evaluated': 'str',
        'workflow_id': 'int',
        'workflow_version': 'int',
        'defined_variables': 'dict(str, object)',
        'follow_up_required': 'bool'
    }

    attribute_map = {
        'flags': 'flags',
        'warnings': 'warnings',
        'execution_id': 'executionId',
        'result': 'result',
        'score': 'score',
        'reason': 'reason',
        'date_evaluated': 'dateEvaluated',
        'workflow_id': 'workflowId',
        'workflow_version': 'workflowVersion',
        'defined_variables': 'definedVariables',
        'follow_up_required': 'followUpRequired'
    }

    def __init__(self, flags=None, warnings=None, execution_id=None, result=None, score=None, reason=None, date_evaluated=None, workflow_id=None, workflow_version=None, defined_variables=None, follow_up_required=None):  # noqa: E501
        """WorkflowExecutionResult - a model defined in Swagger"""  # noqa: E501
        self._flags = None
        self._warnings = None
        self._execution_id = None
        self._result = None
        self._score = None
        self._reason = None
        self._date_evaluated = None
        self._workflow_id = None
        self._workflow_version = None
        self._defined_variables = None
        self._follow_up_required = None
        self.discriminator = None
        if flags is not None:
            self.flags = flags
        if warnings is not None:
            self.warnings = warnings
        if execution_id is not None:
            self.execution_id = execution_id
        if result is not None:
            self.result = result
        if score is not None:
            self.score = score
        if reason is not None:
            self.reason = reason
        if date_evaluated is not None:
            self.date_evaluated = date_evaluated
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if workflow_version is not None:
            self.workflow_version = workflow_version
        if defined_variables is not None:
            self.defined_variables = defined_variables
        if follow_up_required is not None:
            self.follow_up_required = follow_up_required

    @property
    def flags(self):
        """Gets the flags of this WorkflowExecutionResult.  # noqa: E501


        :return: The flags of this WorkflowExecutionResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this WorkflowExecutionResult.


        :param flags: The flags of this WorkflowExecutionResult.  # noqa: E501
        :type: list[str]
        """

        self._flags = flags

    @property
    def warnings(self):
        """Gets the warnings of this WorkflowExecutionResult.  # noqa: E501


        :return: The warnings of this WorkflowExecutionResult.  # noqa: E501
        :rtype: list[RuleSetWarning]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this WorkflowExecutionResult.


        :param warnings: The warnings of this WorkflowExecutionResult.  # noqa: E501
        :type: list[RuleSetWarning]
        """

        self._warnings = warnings

    @property
    def execution_id(self):
        """Gets the execution_id of this WorkflowExecutionResult.  # noqa: E501


        :return: The execution_id of this WorkflowExecutionResult.  # noqa: E501
        :rtype: int
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this WorkflowExecutionResult.


        :param execution_id: The execution_id of this WorkflowExecutionResult.  # noqa: E501
        :type: int
        """

        self._execution_id = execution_id

    @property
    def result(self):
        """Gets the result of this WorkflowExecutionResult.  # noqa: E501


        :return: The result of this WorkflowExecutionResult.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this WorkflowExecutionResult.


        :param result: The result of this WorkflowExecutionResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["APPROVED", "REJECTED", "FLAGGED_FOR_REVIEW", "PAUSED", "ERROR"]  # noqa: E501
        if result not in allowed_values:
            raise ValueError(
                "Invalid value for `result` ({0}), must be one of {1}"  # noqa: E501
                .format(result, allowed_values)
            )

        self._result = result

    @property
    def score(self):
        """Gets the score of this WorkflowExecutionResult.  # noqa: E501


        :return: The score of this WorkflowExecutionResult.  # noqa: E501
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this WorkflowExecutionResult.


        :param score: The score of this WorkflowExecutionResult.  # noqa: E501
        :type: str
        """

        self._score = score

    @property
    def reason(self):
        """Gets the reason of this WorkflowExecutionResult.  # noqa: E501


        :return: The reason of this WorkflowExecutionResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this WorkflowExecutionResult.


        :param reason: The reason of this WorkflowExecutionResult.  # noqa: E501
        :type: list[str]
        """

        self._reason = reason

    @property
    def date_evaluated(self):
        """Gets the date_evaluated of this WorkflowExecutionResult.  # noqa: E501


        :return: The date_evaluated of this WorkflowExecutionResult.  # noqa: E501
        :rtype: str
        """
        return self._date_evaluated

    @date_evaluated.setter
    def date_evaluated(self, date_evaluated):
        """Sets the date_evaluated of this WorkflowExecutionResult.


        :param date_evaluated: The date_evaluated of this WorkflowExecutionResult.  # noqa: E501
        :type: str
        """

        self._date_evaluated = date_evaluated

    @property
    def workflow_id(self):
        """Gets the workflow_id of this WorkflowExecutionResult.  # noqa: E501


        :return: The workflow_id of this WorkflowExecutionResult.  # noqa: E501
        :rtype: int
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this WorkflowExecutionResult.


        :param workflow_id: The workflow_id of this WorkflowExecutionResult.  # noqa: E501
        :type: int
        """

        self._workflow_id = workflow_id

    @property
    def workflow_version(self):
        """Gets the workflow_version of this WorkflowExecutionResult.  # noqa: E501


        :return: The workflow_version of this WorkflowExecutionResult.  # noqa: E501
        :rtype: int
        """
        return self._workflow_version

    @workflow_version.setter
    def workflow_version(self, workflow_version):
        """Sets the workflow_version of this WorkflowExecutionResult.


        :param workflow_version: The workflow_version of this WorkflowExecutionResult.  # noqa: E501
        :type: int
        """

        self._workflow_version = workflow_version

    @property
    def defined_variables(self):
        """Gets the defined_variables of this WorkflowExecutionResult.  # noqa: E501

        this field contains the variables that were defined during your execution  # noqa: E501

        :return: The defined_variables of this WorkflowExecutionResult.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._defined_variables

    @defined_variables.setter
    def defined_variables(self, defined_variables):
        """Sets the defined_variables of this WorkflowExecutionResult.

        this field contains the variables that were defined during your execution  # noqa: E501

        :param defined_variables: The defined_variables of this WorkflowExecutionResult.  # noqa: E501
        :type: dict(str, object)
        """

        self._defined_variables = defined_variables

    @property
    def follow_up_required(self):
        """Gets the follow_up_required of this WorkflowExecutionResult.  # noqa: E501


        :return: The follow_up_required of this WorkflowExecutionResult.  # noqa: E501
        :rtype: bool
        """
        return self._follow_up_required

    @follow_up_required.setter
    def follow_up_required(self, follow_up_required):
        """Sets the follow_up_required of this WorkflowExecutionResult.


        :param follow_up_required: The follow_up_required of this WorkflowExecutionResult.  # noqa: E501
        :type: bool
        """

        self._follow_up_required = follow_up_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowExecutionResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowExecutionResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
